From abc3aa8a0eb0dec01783627296092a2eb600382f Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Mon, 19 Sep 2011 09:35:20 -0400
Subject: [PATCH] - Set group_bind_dn outside of list_groups()

---
 program/include/rcube_session.php |   44 ++++++++++++++++++++++++++------------------
 1 files changed, 26 insertions(+), 18 deletions(-)

diff --git a/program/include/rcube_session.php b/program/include/rcube_session.php
index e4d9a87..27cf694 100644
--- a/program/include/rcube_session.php
+++ b/program/include/rcube_session.php
@@ -6,6 +6,7 @@
  |                                                                       |
  | This file is part of the Roundcube Webmail client                     |
  | Copyright (C) 2005-2011, The Roundcube Dev Team                       |
+ | Copyright (C) 2011, Kolab Systems AG                                  |
  | Licensed under the GNU GPL                                            |
  |                                                                       |
  | PURPOSE:                                                              |
@@ -42,6 +43,7 @@
   private $prev;
   private $secret = '';
   private $ip_check = false;
+  private $logging = false;
   private $keep_alive = 0;
   private $memcache;
 
@@ -53,24 +55,17 @@
     $this->db = $db;
     $this->start = microtime(true);
     $this->ip = $_SERVER['REMOTE_ADDR'];
+    $this->logging = $config->get('log_session', false);
 
     $lifetime = $config->get('session_lifetime', 1) * 60;
     $this->set_lifetime($lifetime);
 
     // use memcache backend
     if ($config->get('session_storage', 'db') == 'memcache') {
-      $this->memcache = new Memcache;
-      $mc_available = 0;
-      foreach ($config->get('memcache_hosts', array()) as $host) {
-        list($host, $port) = explode(':', $host);
-        if (!$port) $port = 11211;
-        // add server and attempt to connect if not already done yet
-        if ($this->memcache->addServer($host, $port) && !$mc_available)
-          $mc_available += intval($this->memcache->connect($host, $port));
-      }
+      $this->memcache = rcmail::get_instance()->get_memcache();
 
       // set custom functions for PHP session management if memcache is available
-      if ($mc_available) {
+      if ($this->memcache) {
         session_set_save_handler(
           array($this, 'open'),
           array($this, 'close'),
@@ -198,8 +193,6 @@
    */
   private function _fixvars($vars, $oldvars)
   {
-    $ts = microtime(true);
-
     if ($oldvars !== false) {
       $a_oldvars = $this->unserialize($oldvars);
       if (is_array($a_oldvars)) {
@@ -319,7 +312,7 @@
   public function gc()
   {
     foreach ($this->gc_handlers as $fct)
-      $fct();
+      call_user_func($fct);
   }
 
 
@@ -328,9 +321,9 @@
    */
   public function cleanup()
   {
-    // current compose information is stored in $_SESSION['compose'], move it to $_SESSION['compose_data']
-    if ($_SESSION['compose']) {
-      $_SESSION['compose_data'][$_SESSION['compose']['id']] = $_SESSION['compose'];
+    // current compose information is stored in $_SESSION['compose'], move it to $_SESSION['compose_data_<ID>']
+    if ($compose_id = $_SESSION['compose']['id']) {
+      $_SESSION['compose_data_'.$compose_id] = $_SESSION['compose'];
       $this->remove('compose');
     }
   }
@@ -573,12 +566,18 @@
     $this->cookie = $_COOKIE[$this->cookiename];
     $result = $this->ip_check ? $_SERVER['REMOTE_ADDR'] == $this->ip : true;
 
+    if (!$result)
+      $this->log("IP check failed for " . $this->key . "; expected " . $this->ip . "; got " . $_SERVER['REMOTE_ADDR']);
+
     if ($result && $this->_mkcookie($this->now) != $this->cookie) {
       // Check if using id from previous time slot
-      if ($this->_mkcookie($this->prev) == $this->cookie)
+      if ($this->_mkcookie($this->prev) == $this->cookie) {
         $this->set_auth_cookie();
-      else
+      }
+      else {
         $result = false;
+        $this->log("Session authentication failed for " . $this->key . "; invalid auth cookie sent");
+      }
     }
 
     return $result;
@@ -606,5 +605,14 @@
     $auth_string = "$this->key,$this->secret,$timeslot";
     return "S" . (function_exists('sha1') ? sha1($auth_string) : md5($auth_string));
   }
+  
+  /**
+   * 
+   */
+  function log($line)
+  {
+    if ($this->logging)
+      write_log('session', $line);
+  }
 
 }

--
Gitblit v1.9.1